@@ -43,6 +43,8 @@ QTdChat::QTdChat(QObject *parent)
     m_messages = new QQmlObjectListModel<QTdMessage>(this, "", "id");
     connect(QTdClient::instance(), &QTdClient::updateChatAction, this, &QTdChat::handleUpdateChatAction);
     connect(QTdClient::instance(), &QTdClient::updateChatActionBar, this, &QTdChat::handleUpdateChatActionBar);
+    connect(QTdClient::instance(), &QTdClient::updateChatIsBlocked, this, &QTdChat::handleUpdateChatIsBlocked);
+    connect(QTdClient::instance(), &QTdClient::foundChatMessages, this, &QTdChat::handleFoundChatMessages);
     connect(m_lastMessage.data(), &QTdMessage::senderChanged, this, &QTdChat::summaryChanged);
     emit messagesChanged();
 }
@@ -53,6 +55,7 @@ void QTdChat::unmarshalJson(const QJsonObject &json)
     updateChatReadInbox(json);
     updateChatReadOutbox(json);
     updateChatTitle(json);
+    updateChatBlocked(json);
 
     m_chatType.reset(QTdChatFactory::createType(json["type"].toObject(), this));
     emit chatTypeChanged(m_chatType.data());
@@ -184,6 +187,10 @@ bool QTdChat::isBot() const {
     return false;
 }
 
+bool QTdChat::isBlocked() const {
+    return m_chatBlocked;
+}
+
 bool QTdChat::canBeReported() const
 {
     return m_canBeReported;
@@ -370,6 +377,21 @@ QObject *QTdChat::messages() const
     return m_messages;
 }
 
+QList<QString> QTdChat::foundMessages() const
+{
+    return m_foundMessages;
+}
+
+QString QTdChat::nextFromMessageId() const
+{
+    return m_nextFromMessageId;
+}
+
+qint32 QTdChat::foundMessagesTotalCount() const
+{
+    return m_foundMessagesTotalCount;
+}
+
 void QTdChat::openChat()
 {
     m_chatOpen = true;
@@ -388,6 +410,12 @@ void QTdChat::closeChat()
     req->setChatId(id());
     QTdClient::instance()->send(req.data());
     m_currentMessageIndex = -1;
+    m_foundMessages = QList<QString>();
+    m_nextFromMessageId = "0";
+    m_foundMessagesTotalCount = 0;
+    emit foundMessagesChanged();
+    emit nextFromMessageIdChanged();
+    emit foundMessagesTotalCountChanged();
     emit closed();
     emit isOpenChanged();
 }
@@ -544,6 +572,12 @@ void QTdChat::updateChatTitle(const QJsonObject &json)
     emit titleChanged(m_title);
 }
 
+void QTdChat::updateChatBlocked(const QJsonObject &json)
+{
+    m_chatBlocked = json["is_blocked"].toBool();
+    emit isBlockedChanged();
+}
+
 void QTdChat::updateChatUnreadMentionCount(const QJsonObject &json)
 {
     m_unreadMentionCount = json["unread_mention_count"];
@@ -594,6 +628,15 @@ void QTdChat::handleUpdateChatActionBar(const QJsonObject &json)
     updateChatActionBar(json["action_bar"].toObject());
 }
 
+void QTdChat::handleUpdateChatIsBlocked(const QJsonObject &data)
+{
+    const qint64 cid = data["chat_id"].toVariant().toLongLong();
+    if (cid != id()) {
+        return;
+    }
+    updateChatBlocked(data);
+}
+
 void QTdChat::handleChatPhotoDownloaded()
 {
     QTdClient::instance()->setAvatarMapEntry(id(), m_chatPhoto->small()->local()->path());
@@ -697,3 +740,39 @@ bool QTdChat::hasChatActionBar() const {
 QTdChatActionBar *QTdChat::chatActionBar() const {
     return m_chatActionBar.data();
 }
+
+void QTdChat::setFoundMessages(QList<QString> foundMessages) {
+    m_foundMessages = QList<QString>();
+    emit foundMessagesChanged();
+}
+
+void QTdChat::setNextFromMessageId(QString &nextFromMessageId) {
+    if (m_nextFromMessageId == nextFromMessageId) {
+        return;
+    }
+    m_nextFromMessageId = nextFromMessageId;
+    emit nextFromMessageIdChanged();
+}
+
+void QTdChat::handleFoundChatMessages(const QJsonObject &json)
+{
+    auto messages = json["messages"].toArray();
+    if (messages.isEmpty()) {
+        return;
+    }
+    for (auto message : messages) {
+        if (message.toObject()["chat_id"].toVariant().toLongLong() != id()) {
+            return;
+        }
+        m_foundMessages.append(message.toObject()["id"].toVariant().toString());
+    }
+    m_foundMessagesTotalCount = json["total_count"].toVariant().toInt();
+    if (messages.size() == m_foundMessagesTotalCount) {
+        m_nextFromMessageId = "0";
+    } else {
+        m_nextFromMessageId = json["next_from_message_id"].toVariant().toString();
+    }
+    emit foundMessagesChanged();
+    emit nextFromMessageIdChanged();
+    emit foundMessagesTotalCountChanged();
+}
