@@ -315,7 +315,7 @@ void QTdClient::init()
     m_events.insert(QStringLiteral("proxy"), [=](const QJsonObject &data) {
         emit proxy(data);
     });
-        m_events.insert(QStringLiteral("seconds"), [=](const QJsonObject &data) {
+    m_events.insert(QStringLiteral("seconds"), [=](const QJsonObject &data) {
         emit seconds(data);
     });
     m_events.insert(QStringLiteral("importedContacts"), [=](const QJsonObject &data) {
@@ -336,6 +336,12 @@ void QTdClient::init()
     m_events.insert(QStringLiteral("chatInviteLinkInfo"), [=](const QJsonObject &data) {
         emit chatInviteLinkInfo(data);
     });
+    m_events.insert(QStringLiteral("updateChatIsBlocked"), [=](const QJsonObject &data) {
+        emit updateChatIsBlocked(data);
+    });
+    m_events.insert(QStringLiteral("foundChatMessages"), [=](const QJsonObject &data) {
+        emit foundChatMessages(data);
+    });
 }
 
 void QTdClient::handleUpdateOption(const QJsonObject &json)
