@@ -34,6 +34,8 @@
 #include "requests/content/imessagecaptioncontent.h"
 #include "requests/content/qtdinputmessagephoto.h"
 #include "chat/requests/qtdreportchatrequest.h"
+#include "requests/qtdtogglemessagesenderisblockedrequest.h"
+#include "chat/requests/qtdsearchchatmessagesrequest.h"
 
 Q_GLOBAL_STATIC(QAudioRecorder, m_voiceNoteRecorder)
 
@@ -852,3 +854,44 @@ void QTdMessageListModel::requestMessageLink(const QString chatId, const QString
     req->setMessageId(messageId.toLong());
     req->sendAsync();
 }
+
+void QTdMessageListModel::toggleMessageSenderIsBlocked(const qint64 id, const bool isBlocked, const QTdMessageSender::SenderType type)
+{
+    QTdMessageSender *sender;
+    QJsonObject messageSender;
+    switch (type) {
+        case QTdMessageSender::User:
+            messageSender = QJsonObject{
+                    {"@type",   "messageSenderUser"},
+                    {"user_id", id}
+            };
+            sender = new QTdMessageSenderUser;
+            sender->unmarshalJson(messageSender, "user_id");
+            break;
+        case QTdMessageSender::Chat:
+            messageSender = QJsonObject{
+                    {"@type",   "messageSenderChat"},
+                    {"chat_id", id}
+            };
+            sender = new QTdMessageSenderChat;
+            sender->unmarshalJson(messageSender, "chat_id");
+            break;
+    }
+    QScopedPointer<QTdToggleMessageSenderIsBlockedRequest> req(new QTdToggleMessageSenderIsBlockedRequest);
+    req->setSenderId(sender);
+    req->setIsBlocked(isBlocked);
+    req->sendAsync();
+    delete sender;
+}
+
+void QTdMessageListModel::searchChatMessages(const QString chatId, const QString query, const QString fromMessageId)
+{
+    QScopedPointer<QTdSearchChatMessagesRequest> req(new QTdSearchChatMessagesRequest);
+    req->setChatId(chatId.toLong());
+    req->setQuery(query);
+    req->setFromMessageId(fromMessageId.toLong());
+    req->setLimit(100);
+    req->setOffset(0);
+    req->setMessageThreadId(0);
+    req->sendAsync();
+}
