@@ -40,6 +40,11 @@ QString QTdMessageSenderUnimplemented::initials() const
     return "";
 }
 
+QJsonObject QTdMessageSenderUnimplemented::marshalJson() const
+{
+    return QJsonObject();
+}
+
 QTdMessageSender *QTdMessageSenderFactory::create(const QJsonObject &json, QObject *parent)
 {
     const QString type = json["@type"].toString();
