@@ -31,4 +31,9 @@ void Users::addUser(const QString &userName, const QString &firstName, const QSt
 
 void Users::addContact(const QString &phoneNumber, const QString &firstName, const QString &lastName, const qint64 userId) {
     QTdUsers::instance()->addContact(phoneNumber, firstName, lastName, userId);
+}
+
+void Users::blockUser(const qint64 userId)
+{
+    QTdUsers::instance()->blockUser(userId);
 }
\ No newline at end of file
